@@ -1,16 +1,18 @@
 """
 Defines various constants and defaults used to configure Besos.
 """
+
+# Python Core Libraries
 import os
 import sys
-
-sys.path.insert(0, "..")
-
-from pathlib import Path
 import warnings
+from pathlib import Path
+
+# BESOS Imports
 from errors import ModeError
 
-baseDir = Path(__file__).resolve().parents[1]
+
+baseDir = Path(__file__).resolve().parents[0]
 # where to store output from simulations, or None for a temporary directory
 out_dir = None
 # folder name to store output in.
@@ -37,6 +39,7 @@ files = {
         "schema": "Energy+.schema.epJSON",
         "idf": "example_idf.idf",
         # note that some places use EnergyPlus-#-#-#/Energyplus.idd as the default idd instead
+        # FIXME: address the above comment
         "idd": "example_idd.idd",
         "epw": "example_epw.epw",
         "xlsx": "example_xlsx.xlsx",
