@@ -3,6 +3,7 @@ Functions to interact with eppy and geomeppy.
 Some functions also support equivalent operations for json buildings.
 """
 
+# Python Core Imports
 import contextlib
 import json
 import os
@@ -15,15 +16,17 @@ from functools import partial
 from pathlib import Path
 from typing import Optional
 
+# External Libraries
 import eppy
 import numpy as np
 import pandas as pd
 from eppy.bunch_subclass import BadEPFieldError
 from shapely.geometry import LineString, Point, Polygon
 
+# BESOS Imports
 import config
 import eplus_funcs as eplus
-from besos.IDF_class import IDF, view_epJSON
+from IDF_class import IDF, view_epJSON
 from errors import ModeError
 
 
