@@ -8,6 +8,8 @@ Currently there are four specific evaluators: EvaluatorEP (for EnergyPlus), `Eva
 `EvaluatorGeneric` (for custom functions), and `AdaptiveSR` (for adaptive sampling).
 The Evaluators wrap their respective modeling tools with the evaluator interface.
 """
+
+# Python Core Libraries
 import copy
 import json
 import os
@@ -20,23 +22,25 @@ from pathlib import Path
 from typing import Callable, Optional, Sequence, Tuple, Union
 from warnings import warn
 
-import config
-import eplus_funcs as eplus
+# External Libraries
 import numpy as np
 import pandas as pd
 import platypus
-import pyehub_funcs as pf
-import sampling
 import yaml
 from dask.dataframe import from_pandas
 from deprecated.sphinx import deprecated
 from pandas import DataFrame as DF
-from problem import Problem
 from pyehub.outputter import output_excel
 from tqdm.auto import tqdm
 
-from besos import eppy_funcs as ef
-from besos.types import PathLike
+# BESOS Imports
+import config
+import eplus_funcs as eplus
+import eppy_funcs as ef
+import pyehub_funcs as pf
+import sampling
+from problem import Problem
+from besostypes import PathLike
 
 
 def _list_cache(
