@@ -12,6 +12,8 @@ to add the corresponding output. For example, if a building does not include an
 Ouptut:Meter object for Electricity:Facility, one will be added if the corresponding
 :class:`MeterReader` is used with that building.
 """
+
+# Python Core Libraries
 import re
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
@@ -20,14 +22,16 @@ from pathlib import Path
 from typing import List, Dict, Tuple, Union, Callable
 from warnings import warn
 
-import config
-import eppy_funcs as ef
+# External Libraries
 import pandas as pd
-from IO_Objects import Objective
-from errors import ModeError
 from packaging.version import Version
 
-from besos.types import PathLike
+# BESOS Imports
+import config
+import eppy_funcs as ef
+from IO_Objects import Objective
+from errors import ModeError
+from besostypes import PathLike
 
 
 def _get_data_dict_regex():
