@@ -3,13 +3,17 @@ Classes used to represent the attributes of the building that can be varied,
 such as the thickness of the insulation, or the window to wall ratio.
 These parameters are separate from the value that they take on during any evaluation of the model.
 """
+
+# Python Core Libraries
 import warnings
 from abc import ABC, abstractmethod
 from typing import Callable, Dict, Iterable, List, Tuple
 
+# External Libraries
 import platypus
 from deprecated.sphinx import deprecated
 
+# BESOS Imports
 import eppy_funcs as ef
 import pyehub_funcs as pf
 from IO_Objects import AnyValue, Descriptor, DummySelector, IOBase, Selector
@@ -17,10 +21,6 @@ from config import range_parameter as conf
 from errors import ModeError
 
 
-# Descriptors
-from besos.types import PathLike
-
-
 class RangeParameter(Descriptor):
     """Represents a value that is contained in an interval.
 
